@@ -106,21 +106,29 @@ class Actor:
                                 await self.log(f"Cancellation of assignment failed. Task was already Done", level=DebugLevel.INFO)
                                 #TODO: Maybe send this to arkitekt as well?
                         else:
-                            raise Exception("Assignment never was at this pod. something went wrong")
-
+                            unassign_done = UnassignDoneMessage(data={
+                                    "assignation": message.data.assignation
+                                },
+                                    meta = {
+                                        "reference": message.meta.reference,
+                                        "extensions": message.meta.extensions
+                                    }
+                                )
+                            await self.connector.forward(unassign_done)
+                            await self.log(f"There was nether an assignment on this Worker... Sending Done", level=DebugLevel.INFO)
                     else:
                         raise Exception(f"Type not known {message}")
 
                     self.queue.task_done()
+                
+            except Exception as e:
+                console.print_exception()
 
+        except asyncio.CancelledError:
+            await self.on_unprovide(self.provide_handler)
+            await self.log("Actor was beeing cancelled")
+            raise
 
-            except asyncio.CancelledError:
-                await self.on_unprovide(self.provide_handler)
-                await self.log("Actor was beeing cancelled")
-                raise
-
-        except Exception as e:
-            console.print_exception()
 
     
     def check_if_assignation_cancelled(self, task: Task):
