@@ -3,7 +3,7 @@ from bergen.schemas.arkitekt.mutations.host import HOST_GQL
 from bergen.schema import DataModel
 from bergen.enums import ClientType, DataPointType
 from bergen.clients.default import Bergen
-
+import asyncio
 
 class PointBergen(Bergen):
 
@@ -29,7 +29,7 @@ class PointBergen(Bergen):
         params = []
         for model in self.model_registry.values():
             params = {"identifier": model.identifier, "extenders": model.extenders}
-            HOST_GQL.run(ward=self.main_ward, variables=params)
+            self.loop.run_until_complete(HOST_GQL.run(ward=self.main_ward, variables=params))
 
         
 
